@@ -6,7 +6,7 @@ except ImportError:
     # python3
     from urllib.parse import urlparse, urlunparse
 
-from flask_restful import types, marshal
+from flask_restful import inputs, marshal
 from flask import url_for
 
 __all__ = ["String", "FormattedString", "Url", "DateTime", "Float",
@@ -81,7 +81,8 @@ class Raw(object):
         self.default = default
 
     def format(self, value):
-        """Formats a field's value. No-op by default, concrete fields should
+        """Formats a field's value. No-op by default - field classes that 
+        modify how the value of existing object keys should be presented should 
         override this and apply the appropriate formatting.
 
         :param value: The value to format
@@ -97,7 +98,11 @@ class Raw(object):
 
     def output(self, key, obj):
         """Pulls the value for the given key from the object, applies the
-        field's formatting and returns the result.
+        field's formatting and returns the result. If the key is not found 
+        in the object, returns the default value. Field classes that create 
+        values which do not require the existence of the key in the object 
+        should override this and return the desired value.
+        
         :exception MarshallingException: In case of formatting problem
         """
 
@@ -116,6 +121,10 @@ class Nested(Raw):
     :param dict nested: The dictionary to nest
     :param bool allow_null: Whether to return None instead of a dictionary
         with null keys, if a nested dictionary has all-null keys
+    :param kwargs: if ``default`` keyword argument is present, a nested dictionary
+        will be marshaled as its value if nested dictionary is all-null keys
+        (e.g. lets you return an empty JSON object instead of null)
+    :keyword default
     """
 
     def __init__(self, nested, allow_null=False, **kwargs):
@@ -125,13 +134,24 @@ class Nested(Raw):
 
     def output(self, key, obj):
         value = get_value(key if self.attribute is None else self.attribute, obj)
-        if self.allow_null and value is None:
-            return None
+        if value is None:
+            if self.allow_null:
+                return None
+            elif self.default is not None:
+                return self.default
 
         return marshal(value, self.nested)
 
 
 class List(Raw):
+    """
+    Field for marshalling lists of other fields.
+
+    See :ref:`list-field` for more information.
+
+    :param cls_or_instance: The field type the list will contain.
+    """
+
     def __init__(self, cls_or_instance, **kwargs):
         super(List, self).__init__(**kwargs)
         error_msg = ("The type of the list elements must be a subclass of "
@@ -145,22 +165,25 @@ class List(Raw):
                 raise MarshallingException(error_msg)
             self.container = cls_or_instance
 
+    def format(self, value):
+        # Convert all instances in typed list to container type
+        if isinstance(value, set):
+            value = list(value)
+
+        return [
+            self.container.output(idx,
+                                  val if isinstance(val, dict) and
+                                         not isinstance(self.container, Nested)
+                                  and not type(self.container) is Raw
+                                  else value)
+            for idx, val in enumerate(value)
+        ]
+
     def output(self, key, data):
         value = get_value(key if self.attribute is None else self.attribute, data)
         # we cannot really test for external dict behavior
         if is_indexable_but_not_string(value) and not isinstance(value, dict):
-            # Convert all instances in typed list to container type
-            if isinstance(value, set):
-                value = list(value)
-
-            return [
-                self.container.output(idx,
-                                      val if isinstance(val, dict) and
-                                      not isinstance(self.container, Nested)
-                                      and not type(self.container) is Raw
-                                      else value)
-                for idx, val in enumerate(value)
-            ]
+            return self.format(value)
 
         if value is None:
             return self.default
@@ -169,6 +192,11 @@ class List(Raw):
 
 
 class String(Raw):
+    """
+    Marshal a value as a string. Uses :py:class:`six.text_type` so values will
+    be converted to :py:class:`unicode` in python2 and :py:class:`str` in
+    python3.
+    """
     def format(self, value):
         try:
             return six.text_type(value)
@@ -199,12 +227,38 @@ class Integer(Raw):
 
 
 class Boolean(Raw):
+    """
+    Field for outputting a boolean value.
+
+    Empty collections such as ``""``, ``{}``, ``[]``, etc. will be converted to
+    ``False``.
+    """
     def format(self, value):
         return bool(value)
 
 
 class FormattedString(Raw):
+    """
+    FormattedString is used to interpolate other values from
+    the response into this field. The syntax for the source string is
+    the same as the string `format` method from the python stdlib.
+
+    Ex::
+
+        fields = {
+            'name': fields.String,
+            'greeting': fields.FormattedString("Hello {name}")
+        }
+        data = {
+            'name': 'Doug',
+        }
+        marshal(data, fields)
+    """
     def __init__(self, src_str):
+        """
+        :param string src_str: the string to format with the other
+        values from the response.
+        """
         super(FormattedString, self).__init__()
         self.src_str = six.text_type(src_str)
 
@@ -229,7 +283,7 @@ class Url(Raw):
     def output(self, key, obj):
         try:
             data = to_marshallable_type(obj)
-            o = urlparse(url_for(self.endpoint, _external = self.absolute, **data))
+            o = urlparse(url_for(self.endpoint, _external=self.absolute, **data))
             if self.absolute:
                 scheme = self.scheme if self.scheme is not None else o.scheme
                 return urlunparse((scheme, o.netloc, o.path, "", "", ""))
@@ -246,7 +300,7 @@ class Float(Raw):
 
     def format(self, value):
         try:
-            return repr(float(value))
+            return float(value)
         except ValueError as ve:
             raise MarshallingException(ve)
 
@@ -262,11 +316,26 @@ class Arbitrary(Raw):
 
 
 class DateTime(Raw):
-    """Return a RFC822-formatted datetime string in UTC"""
+    """
+    Return a formatted datetime string in UTC. Supported formats are RFC 822
+    and ISO 8601.
+
+    :param: str dt_format: rfc822 or iso8601
+    """
+    def __init__(self, dt_format='rfc822', **kwargs):
+        super(DateTime, self).__init__(**kwargs)
+        self.dt_format = dt_format
 
     def format(self, value):
         try:
-            return types.rfc822(value)
+            if self.dt_format == 'rfc822':
+                return inputs.rfc822(value)
+            elif self.dt_format == 'iso8601':
+                return inputs.iso8601(value)
+            else:
+                raise MarshallingException(
+                    'Unsupported date format %s' % self.dt_format
+                )
         except AttributeError as ae:
             raise MarshallingException(ae)
 
@@ -274,6 +343,9 @@ ZERO = MyDecimal()
 
 
 class Fixed(Raw):
+    """
+    A decimal number with a fixed precision.
+    """
     def __init__(self, decimals=5, **kwargs):
         super(Fixed, self).__init__(**kwargs)
         self.precision = MyDecimal('0.' + '0' * (decimals - 1) + '1')
@@ -284,4 +356,6 @@ class Fixed(Raw):
             raise MarshallingException('Invalid Fixed precision number.')
         return six.text_type(dvalue.quantize(self.precision, rounding=ROUND_HALF_EVEN))
 
+
+"""Alias for :py:class:`~fields.Fixed`"""
 Price = Fixed
