@@ -1,3 +1,8 @@
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
+
 from werkzeug.http import HTTP_STATUS_CODES
 
 
